### Name: optimizeNetwork
### Title: Optimization of networks
### Aliases: optimizeNetwork
### Keywords: spatial

### ** Examples

## Not run: 
##D library(intamapInteractive)
##D library(maptools)
##D # use SIC2004 dataset
##D data(sic2004)
##D # load a shape file of the study area
##D rpath = system.file("inst/external", package="intamapInteractive")
##D setwd(rpath)
##D candidates = readShapePoly("sic2004")
##D # load the input for the observation and prediction locations
##D # including the covariates for UK, and changing to more intuitive 
##D # variable names
##D coordinates(sic.val) = ~x+y
##D observations = sic.val["dayx"] 
##D predGrid= sic.grid
##D # limit the number of prediction locations to have faster UK 
##D # computations
##D nGrid = length(predGrid$x)
##D predGrid = predGrid[sample(seq(1,nGrid),1000),]
##D coordinates(predGrid) = ~x+y
##D # fit the variogram model (using function fit.variogram from package
##D # gstat)
##D model = fit.variogram(variogram(dayx~x+y, observations), vgm(50, "Sph", 250000, 250))
##D plot(variogram(dayx~x+y, observations), model=model)
##D # compute the Mukv of the current network
##D initMukv <- calculateMukv(observations, predGrid, model)
##D print(initMukv)
##D # delete optimally 20 stations from current network with method "ssa"
##D # (spatial simulated annealing) and criterion "mukv"
##D 
##D windows()
##D optim = optimizeNetwork(observations, predGrid, candidates, method = "ssa", 
##D             action = "del", nDiff = 20, model = model, criterion = "MUKV", plot = TRUE )
## End(Not run)



